"""Defining the vocabulary.

.. autosummary::
   :toctree: .

   readoutS
   READOUT_PLATFORMS
"""

from ._core import READOUT_PLATFORMS, readoutS  # noqa
